@@ -15,7 +15,7 @@ setGeneric("xmlToDataFrame",
   #     <var1>value</var1>
   #     <var2>value</var2>
   #     <var3>value</var3>
-  #   </obs>  
+  #   </obs>
   #  </top>
   #
   # This can handle cases where not all observations have the same
@@ -24,29 +24,29 @@ setGeneric("xmlToDataFrame",
   # z = xmlToDataFrame("~/size.xml")
   # z = xmlToDataFrame("~/size.xml", c("integer", "integer", "numeric"))
   #
-           
-           function(doc, colClasses = NULL, homogeneous = NA, collectNames = TRUE, nodes = list(), stringsAsFactors = default.stringsAsFactors())
+
+           function(doc, colClasses = NULL, homogeneous = NA, collectNames = TRUE, nodes = list(), stringsAsFactors = FALSE)
               standardGeneric("xmlToDataFrame"))
 
 setMethod("xmlToDataFrame", "character",
              # parse the XML document if it is a file name and
-             # not a regular XML document already.          
-          function(doc, colClasses = NULL, homogeneous = NA, collectNames = TRUE, nodes = list(), stringsAsFactors = default.stringsAsFactors())
+             # not a regular XML document already.
+          function(doc, colClasses = NULL, homogeneous = NA, collectNames = TRUE, nodes = list(), stringsAsFactors = FALSE)
                xmlToDataFrame(xmlParse(doc), colClasses, homogeneous, collectNames, stringsAsFactors = stringsAsFactors))
 
 
 
 setMethod("xmlToDataFrame", c("XMLInternalDocument", nodes = "missing"),
-  function(doc, colClasses = NULL, homogeneous = NA, collectNames = TRUE, nodes = list(), stringsAsFactors = default.stringsAsFactors())
+  function(doc, colClasses = NULL, homogeneous = NA, collectNames = TRUE, nodes = list(), stringsAsFactors = FALSE)
       xmlToDataFrame(doc, colClasses, homogeneous, collectNames, nodes = xmlChildren(xmlRoot(doc)), stringsAsFactors))
 
-tmp = 
-function(doc, colClasses = NULL, homogeneous = NA, collectNames = TRUE, nodes = list(), stringsAsFactors = default.stringsAsFactors())
+tmp =
+function(doc, colClasses = NULL, homogeneous = NA, collectNames = TRUE, nodes = list(), stringsAsFactors = FALSE)
 {
 
   if(length(nodes) == 0)
     return(data.frame())
-  
+
     # Find out how many fields there.
   nfields = sapply(nodes, xmlSize)
   nvar = max(nfields)
@@ -55,15 +55,15 @@ function(doc, colClasses = NULL, homogeneous = NA, collectNames = TRUE, nodes =
      varNames = unique(unlist( lapply(nodes, names) ))
   else
      varNames = names(nodes[[which.max(nfields)]])
-  
-  if(is.na(homogeneous)) 
+
+  if(is.na(homogeneous))
     homogeneous = all(nfields == nvar) && all(sapply(nodes[-1], function(x) all(names(x) == varNames)))
 
 
-  if(!homogeneous) 
+  if(!homogeneous)
     return(fromRaggedXML2DataFrame(nodes, varNames, c(length(nfields), length(varNames)), colClasses, stringsAsFactors))
-    
-     # Function to operate on each 
+
+     # Function to operate on each
   fun = function(x) {
            tmp = xmlSApply(x, xmlValue)
            length(tmp) = nvar
@@ -75,7 +75,7 @@ function(doc, colClasses = NULL, homogeneous = NA, collectNames = TRUE, nodes =
   ans = matrix(vals, length(nfields), byrow = TRUE)
 
 
-  
+
   ans =
     if(length(colClasses)) {
        as.data.frame(lapply(seq(along = colClasses),
@@ -91,7 +91,7 @@ function(doc, colClasses = NULL, homogeneous = NA, collectNames = TRUE, nodes =
 }
 
 bob =
-function(doc, colClasses = NULL, homogeneous = NA, collectNames = TRUE, nodes = list(), stringsAsFactors = default.stringsAsFactors())
+function(doc, colClasses = NULL, homogeneous = NA, collectNames = TRUE, nodes = list(), stringsAsFactors = FALSE)
   xmlToDataFrame(nodes = doc, colClasses = colClasses, homogeneous = homogeneous, collectNames = collectNames, stringsAsFactors = stringsAsFactors)
 
 setMethod("xmlToDataFrame", c(nodes = "XMLNodeSet"), tmp)
@@ -104,7 +104,7 @@ setMethod("xmlToDataFrame", "XMLInternalNodeList",   bob)
 setMethod("xmlToDataFrame", "list",   bob)
 
 setMethod("xmlToDataFrame", "XMLInternalElementNode",
-          function(doc, colClasses = NULL, homogeneous = NA, collectNames = TRUE, nodes = list(), stringsAsFactors = default.stringsAsFactors())
+          function(doc, colClasses = NULL, homogeneous = NA, collectNames = TRUE, nodes = list(), stringsAsFactors = FALSE)
             xmlToDataFrame(nodes = xmlChildren(doc), colClasses = colClasses, homogeneous = homogeneous, collectNames = collectNames, stringsAsFactors = stringsAsFactors))
 
 fromRaggedXML2DataFrame =
@@ -115,29 +115,29 @@ fromRaggedXML2DataFrame =
   # the field names across all nodes.
   #
   # o = fromRaggedXML2DataFrame("size2.xml")
-  # o = fromRaggedXML2DataFrame("size1.xml")  
+  # o = fromRaggedXML2DataFrame("size1.xml")
   #
 function(nodes, varNames = unique(unlist( lapply(nodes, names) )),
           dims = c(length(nodes), length(varNames)),   colClasses = NULL,
-          stringsAsFactors = default.stringsAsFactors())
+          stringsAsFactors = FALSE)
 {
   #XXX
   if(is.character(nodes))
     nodes = xmlChildren(xmlRoot(xmlParse(nodes)))
-  
+
    # create an empty data frame with as many rows and columns as needed.
   ans = as.data.frame(replicate(dims[2], rep(as.character(NA), dims[1]), simplify = FALSE), stringsAsFactors = FALSE)
   names(ans) = varNames
 
     # Fill in the rows based on the names.
-  for(i in seq(length = dims[1])) 
+  for(i in seq(length = dims[1]))
      ans[i, names(nodes[[i]])] = xmlSApply(nodes[[i]], xmlValue)
 
 
     # Convert the columns to the specified classes if specified.
     # Should drop cols with NULL. Also guess those with NA.
   if(length(colClasses))  {
-    i = ! sapply(colClasses, is.null) 
+    i = ! sapply(colClasses, is.null)
     ans = ans[ i ]
     varNames = varNames[i]
     colClasses = colClasses[ i ]
@@ -147,7 +147,7 @@ function(nodes, varNames = unique(unlist( lapply(nodes, names) )),
                                 }), stringsAsFactors = stringsAsFactors)
   }
 
-  names(ans) = varNames  
+  names(ans) = varNames
 
   ans
 }
@@ -179,14 +179,14 @@ setMethod("xmlAttrsToDataFrame", "list",
                # assuming these are all nodes.
 
              combineNamedVectors(lapply(doc, xmlAttrs), attrs, omit, ...)
-           
+
            })
 setMethod("xmlAttrsToDataFrame", "XMLInternalNodeList",
            function(doc, attrs = character(), omit = character(), ...) {
                # assuming these are all nodes.
 
              combineNamedVectors(lapply(doc, xmlAttrs), attrs, omit, ...)
-           
+
            })
 
 inAllRecords =
@@ -199,17 +199,17 @@ function(x)
 allNames =
 function(x)
   unique( unlist(lapply(x, names))  )
-          
+
 
 combineNamedVectors   =
 function(els, attrs = character(), omit = character(), ...)
 {
   if(is.function(attrs))
      attrs = attrs(els)
-  
+
   if(!length(attrs)) {
     attrs = allNames(els)
-    
+
     if(length(omit))
       attrs = setdiff(attrs, omit)
   }
@@ -218,7 +218,7 @@ function(els, attrs = character(), omit = character(), ...)
     warning("no elements to combine across records")
     return(data.frame())
   }
-  
+
   values = lapply(els, function(x) {
                          structure(x[attrs], names = attrs)
                        })
@@ -226,4 +226,4 @@ function(els, attrs = character(), omit = character(), ...)
   rownames(ans) = NULL
   ans
 }
-  
+
